@@ -102,7 +102,6 @@ def PG_network(A, t, V_gen, V_con, K_0 = 1.63, P_gen = 1.5, P_con = 1, alpha = 0
     theta, omega = PG_steady_state(N, P, K)
     Fs = []
     dt = t[1]-t[0]
-    e_cut = [e_cut[0]-1, e_cut[1]-1]
     for t_i in t:
         if t_i > 1: # remove line 4-2 at 1 second
             K[e_cut[0]][e_cut[1]], K[e_cut[1]][e_cut[0]] = 0, 0
@@ -134,15 +133,15 @@ if __name__ == '__main__':
     import matplotlib.pyplot as plt
     import numpy as np
     
-    t = np.linspace(0,12, 5000)
-    P_gen = 1
-    P_con = 1
-    K_0 = 1.63
-    I_0 = 1 
-    damping = 0.5
-    alpha = 0.6
-    V_gen = np.array([1, 4]) #vertices indices of generates and consumers
-    V_con = np.array([0, 2, 3])
+    t = np.linspace(0,12, 5000) #the time which the simulation will be solved for.
+    P_gen = 1.5 #the amount of power generated by the generators.
+    P_con = 1 #the power consumed by the consumers.
+    K_0 = 1.63 #the capacitance of the lines
+    I_0 = 1 #inertia of the power generators and consumers
+    damping = 0.5 #the damping in the power oscillations or losses in the transmission of power.
+    alpha = 0.6 #a factor of safety for for the capacity of the power lines
+    V_gen = np.array([1, 4]) #vertices indices of generates
+    V_con = np.array([0, 2, 3]) #vertices indices of consumers
     A = np.array([[0, 1, 1, 0, 1],
                   [1, 0, 1, 1, 0],
                   [1, 1, 0, 1, 0],
@@ -151,7 +150,7 @@ if __name__ == '__main__':
     
     
     
-    Fs, E = PG_network(A, t, V_gen, V_con, K_0, P_gen, P_con, alpha, I_0, damping, e_cut = (2,4))
+    Fs, E = PG_network(A, t, V_gen, V_con, K_0, P_gen, P_con, alpha, I_0, damping, e_cut = (1,3))
     
     
     #---------------PLOTTING-------------------
@@ -159,7 +158,7 @@ if __name__ == '__main__':
     plt.figure(figsize = (10,5))
     TextSize = 35
     for i in range(len(Fs)):
-        plt.plot(t, Fs[i], label = '$('+str(E[i][0]+1)+','+str(E[i][1]+1)+')$')
+        plt.plot(t, Fs[i], label = '$('+str(E[i][0])+','+str(E[i][1])+')$')
     plt.plot([0,max(t)], [alpha*K_0, alpha*K_0], 'k--')
     
     plt.grid()
